@@ -27,10 +27,10 @@ class SolutionByTextHTTPInterface(object):
         """
         return "%s%s" % (self.base_url, self.service_end_point)
 
-    def _post(self, data):
+    def _post(self, params):
         headers = {'content-type': 'application/json'}
         absolute_url = self.get_full_path()
-        return requests.post(absolute_url, data=json.dumps(data), headers=headers)
+        return requests.post(absolute_url, data=json.dumps(params), headers=headers)
 
     def _get(self, params=None):
         absolute_url = self.get_full_path()
